@@ -18,9 +18,11 @@ class App:
         self.routes = {}
         self.host = "127.0.0.1"
         self.port = 5000
+        
+        self.templates_dir = templates_dir
 
         self.templates_env = Environment(
-            loader=FileSystemLoader(os.path.abspath(templates_dir)))
+            loader=FileSystemLoader(os.path.abspath(self.templates_dir)))
 
         if exception_handler is None:
             self.exception_handler = DefaultExceptionHandler(self)
