@@ -5,7 +5,7 @@ with open("README.md", "r", encoding="utf-8") as fh:
 
 setuptools.setup(
     name="arcframework",  # Replace with your own username
-    version="1.0.4",
+    version="1.0.6",
     author="Rayyan Cyclegar",
     author_email="aboominister@gmail.com",
     description="A Python micro web framework for creating dynamic websites.",
@@ -20,6 +20,6 @@ setuptools.setup(
     ],
     python_requires='>=3.8',
     install_requires=[
-        'webob', "cherrypy", "whitenoise", "parse"
+        'webob', "cherrypy", "whitenoise", "parse", "jinja2"
     ]
 )
